… | OiRA

Help

1. Preparació
2. Implicació
3. Identificació + Avaluació
   1. 1 Commercial manned guarding
   2. Ω Riscos afegits (per vostè)
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - No respost
   - Posposat
   - Correcte
   - Actuar
4. Pla d'acció
5. Informe
6. Grau d’emplenament 0%

## Descriviu el risc…

Aquest risc és acceptable o sota control? No, calen més mesures Sí, el risc residual és acceptable

Select the priority of this risk Low Medium High
Informació
Carregar una imatgelabel_upload_image
Comentaris

Scroll to top
Back

## add-risk.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More